from PySide2.QtCore import *
from PySide2.QtWidgets import *
from PySide2.QtGui import *
import os

class DragDropWidget(QWidget):
    dropped = Signal(str)
    clicked = Signal()
    def __init__(self, parent=None):
        super(DragDropWidget, self).__init__(parent)
        self.setAcceptDrops(True)

    def dragEnterEvent(self, event):
        if event.mimeData().hasUrls:
            event.accept()
        else:
            event.ignore()

    def dragMoveEvent(self, event):
        if event.mimeData().hasUrls:
            if len(event.mimeData().urls()) != 1:
                event.ignore()
            else:
                event.setDropAction(Qt.CopyAction)
                event.accept()
        else:
            event.ignore()

    def dropEvent(self, event):
        if event.mimeData().hasUrls:
            event.setDropAction(Qt.CopyAction)
            event.accept()
            if len(event.mimeData().urls()) != 1:
                event.ignore()
            else:
                url = event.mimeData().urls()[
                    0].toLocalFile()
                if os.path.exists(url):
                    self.dropped.emit(url)

        else:
            event.ignore()

    def mousePressEvent(self, event):
        self.clicked.emit()


"""Errors dictionary for thoryvos."""
Error = {
    1: "An Unexpected Error has occured.",
    2: "Invalid Encryption Mode.",
    3: "Data File is empty.",
    4: "Not a wave file.",
    5: "Invalid URL.",
    6: "File does not exist.",
    7: "LSB must be specified for data recovery.",
    8: "nbytes must be specified for data recovery."
}



"""thoryvos backend for encryption & decryption."""
# Importing Dependenciess
from Crypto.Cipher import AES, Salsa20, DES3
from Crypto import Random
from Crypto.Protocol.KDF import scrypt
from hashlib import sha512
from Crypto.Util.Padding import pad, unpad


def get_key(password: str, length: int):
    """Generate the key according to password."""
    salt = sha512(password.encode()).hexdigest()
    return scrypt(password, salt, length, N=2**20, r=8, p=1)


class Encrypt:
    """Encrypts data."""

    def __init__(self, infile: str) -> None:
        """Open the data in the infile."""
        self.data = open(infile, 'rb').read()

    def AES(self, password: str) -> bytes:
        """Encrypt data according to AES algorithm."""
        # Generating the key according to password
        key = get_key(password, 32)

        # Generating random IV for encryption.
        iv = Random.new().read(AES.block_size)

        # Encrypting the data.
        cipher_object = AES.new(key, AES.MODE_CBC, IV=iv)
        return (iv + cipher_object.encrypt(pad(self.data, 16)))

    def Salsa20(self, password: str) -> bytes:
        """Encrypt data according to Salsa20 algorithm."""
        # Generating the key according to password
        key = get_key(password, 32)

        # Encrypting the data.
        cipher_object = Salsa20.new(key)
        return (cipher_object.nonce + cipher_object.encrypt(self.data))

    def DES(self, password: str) -> bytes:
        """Encrypt data according to DES3 algorithm."""
        # Generating the key according to password
        key = DES3.adjust_key_parity(get_key(password, 24))

        # Encrypting the data
        cipher_object = DES3.new(key, DES3.MODE_CBC)
        return (cipher_object.iv + cipher_object.encrypt(pad(self.data, 8)))


class Decrypt:
    """Decrypts Data."""

    def __init__(self, infile: str) -> None:
        """Open the data in the infile and sets the IV."""
        data = open(infile, 'rb').read()
        self.data = data[16:]
        self.extension = unpad(data[:16], 16).decode()

    def AES(self, password: str) -> bytes:
        """Decrypt data according to AES algorithm."""
        # Generating the key according to password
        key = get_key(password, 32)

        # Splitting data into IV & Data
        iv = self.data[:16]
        data = self.data[16:]

        # Decrypting the data
        cipher_object = AES.new(key, AES.MODE_CBC, IV=iv)
        return unpad(cipher_object.decrypt(data), 16)

    def Salsa20(self, password: str) -> bytes:
        """Decrypt data according to Salsa20 algorithm."""
        # Generating the key according to password
        key = get_key(password, 32)

        # Splitting data into nonce & Data
        nonce = self.data[:8]
        data = self.data[8:]

        # Decrypting the data. Here the 'IV' is the nonce
        cipher_object = Salsa20.new(key, nonce)
        return cipher_object.decrypt(data)

    def DES(self, password: str) -> bytes:
        """Decrypt data according to DES algorithm."""
        # Generating the key according to password
        key = DES3.adjust_key_parity(get_key(password, 24))

        # Splitting data into IV & Data
        iv = self.data[:8]
        data = self.data[8:]

        # Decrypting the data
        cipher_object = DES3.new(key, DES3.MODE_CBC, IV=iv)
        return unpad(cipher_object.decrypt(data), 8)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'Main.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PySide2 import QtCore, QtGui, QtWidgets
from .GUI_helper import DragDropWidget
from .fonts import *
import os


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        self.fontDB = QtGui.QFontDatabase()
        self.fontDB.addApplicationFont(f":/fonts/fonts/CabinSketch-Bold.ttf")
        self.fontDB.addApplicationFont(
            f":/fonts/fonts/CabinSketch-Regular.ttf")
        self.fontDB.addApplicationFont(
            f":/fonts/fonts/CFNightofTerrorPERSONAL-Reg.ttf")
        self.fontDB.addApplicationFont(f":/fonts/fonts/Courgette-Regular.ttf")
        self.fontDB.addApplicationFont(
            f":/fonts/fonts/DEADLY KILLERS.ttf")
        self.fontDB.addApplicationFont(
            f":/fonts/fonts/FEASFBI_.ttf")
        self.fontDB.addApplicationFont(f":/fonts/fonts/FEASFBI.ttf")
        self.fontDB.addApplicationFont(
            f":/fonts/fonts/FEASFBRG.ttf")
        self.fontDB.addApplicationFont(
            f":/fonts/fonts/Lemon-Regular.ttf")
        self.fontDB.addApplicationFont(
            f":/fonts/fonts/Martyric_PersonalUse.ttf")
        self.fontDB.addApplicationFont(
            f":/fonts/fonts/monbaiti.ttf")
        self.fontDB.addApplicationFont(
            f":/fonts/fonts/PirataOne-Regular.ttf")
        self.fontDB.addApplicationFont(
            ":/fonts/fonts/RW-creepsville.ttf")
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1080, 400)
        MainWindow.setMinimumSize(QtCore.QSize(1080, 400))
        MainWindow.setMaximumSize(QtCore.QSize(1080, 500))
        MainWindow.setStyleSheet("background-color: rgb(45, 45, 45);")
        MainWindow.setIconSize(QtCore.QSize(80, 80))
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.TopBar = QtWidgets.QFrame(self.centralwidget)
        self.TopBar.setMaximumSize(QtCore.QSize(16777215, 45))
        self.TopBar.setStyleSheet("background-color: qlineargradient(spread:pad, x1:0.542, y1:0.557, x2:1, y2:0, stop:0 rgba(180, 35, 22, 255), stop:0.631841 rgba(211, 75, 21, 254));")
        self.TopBar.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.TopBar.setFrameShadow(QtWidgets.QFrame.Raised)
        self.TopBar.setObjectName("TopBar")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.TopBar)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.Menu = QtWidgets.QFrame(self.TopBar)
        self.Menu.setMaximumSize(QtCore.QSize(80, 45))
        self.Menu.setStyleSheet("background-color: qlineargradient(spread:pad, x1:0.447473, y1:0.836, x2:0.537313, y2:0, stop:0 rgba(180, 35, 22, 255), stop:0.631841 rgba(211, 75, 21, 254));\n"
"selection-background-color: rgb(159, 8, 23);")
        self.Menu.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.Menu.setFrameShadow(QtWidgets.QFrame.Raised)
        self.Menu.setLineWidth(0)
        self.Menu.setObjectName("Menu")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.Menu)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.ToggleMenu = QtWidgets.QPushButton(self.Menu)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ToggleMenu.sizePolicy().hasHeightForWidth())
        self.ToggleMenu.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Pirata One")
        font.setPointSize(18)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        font.setStyleStrategy(QtGui.QFont.PreferAntialias)
        self.ToggleMenu.setFont(font)
        self.ToggleMenu.setStyleSheet("QPushButton {\n"
"    color: qlineargradient(spread:pad, x1:0.498, y1:0, x2:0.492, y2:0.903, stop:0 rgba(159, 8, 23, 255), stop:0.393035 rgba(123, 37, 61, 255));\n"
"border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    color: rgba(255, 255, 255, 180);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.184, y1:0.705, x2:0.923851, y2:0.182, stop:0.0298507 rgba(183, 39, 22, 255), stop:0.701493 rgba(45, 45, 45, 246));\n"
"}")
        self.ToggleMenu.setObjectName("ToggleMenu")
        self.verticalLayout_2.addWidget(self.ToggleMenu)
        self.horizontalLayout.addWidget(self.Menu)
        self.Spacer = QtWidgets.QFrame(self.TopBar)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Spacer.sizePolicy().hasHeightForWidth())
        self.Spacer.setSizePolicy(sizePolicy)
        self.Spacer.setMaximumSize(QtCore.QSize(16777215, 45))
        self.Spacer.setStyleSheet("background-color: qlineargradient(spread:pad, x1:0.507955, y1:1, x2:0.497299, y2:0, stop:0.0199005 rgba(45, 45, 45, 255), stop:0.880597 rgba(0, 0, 0, 255));")
        self.Spacer.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.Spacer.setFrameShadow(QtWidgets.QFrame.Raised)
        self.Spacer.setObjectName("Spacer")
        self.AppName = QtWidgets.QLabel(self.Spacer)
        self.AppName.setGeometry(QtCore.QRect(0, 0, 1001, 43))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.AppName.sizePolicy().hasHeightForWidth())
        self.AppName.setSizePolicy(sizePolicy)
        self.AppName.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Creepsville")
        font.setPointSize(20)
        font.setBold(True)
        font.setItalic(True)
        font.setUnderline(False)
        font.setWeight(75)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferAntialias)
        self.AppName.setFont(font)
        self.AppName.setStyleSheet("color: rgb(159, 8, 23);\n"
"background-color: rgba(0,0,0,0);")
        self.AppName.setAlignment(QtCore.Qt.AlignCenter)
        self.AppName.setObjectName("AppName")
        self.CreatedBy = QtWidgets.QLabel(self.Spacer)
        self.CreatedBy.setGeometry(QtCore.QRect(14, 20, 971, 20))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.CreatedBy.sizePolicy().hasHeightForWidth())
        self.CreatedBy.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Comic Sans MS")
        font.setPointSize(8)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferAntialias)
        self.CreatedBy.setFont(font)
        self.CreatedBy.setStyleSheet("color: rgb(61, 57, 63);\n"
"border-radius: 100px;\n"
"background-color: rgba(0, 0, 0, 0);\n"
"")
        self.CreatedBy.setAlignment(QtCore.Qt.AlignBottom|QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing)
        self.CreatedBy.setObjectName("CreatedBy")
        self.horizontalLayout.addWidget(self.Spacer)
        self.verticalLayout.addWidget(self.TopBar)
        self.Content = QtWidgets.QFrame(self.centralwidget)
        self.Content.setMinimumSize(QtCore.QSize(0, 0))
        self.Content.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.Content.setFrameShadow(QtWidgets.QFrame.Raised)
        self.Content.setObjectName("Content")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.Content)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.LeftMenu = QtWidgets.QFrame(self.Content)
        self.LeftMenu.setMinimumSize(QtCore.QSize(45, 0))
        self.LeftMenu.setMaximumSize(QtCore.QSize(80, 16777215))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.LeftMenu.setFont(font)
        self.LeftMenu.setStyleSheet("background-color: qlineargradient(spread:pad, x1:0.472, y1:0, x2:0.4669, y2:0.813, stop:0.0298507 rgba(180, 35, 22, 255), stop:0.706468 rgba(74, 74, 74, 100));\n"
"selection-background-color: qlineargradient(spread:pad, x1:0.507955, y1:1, x2:0.497299, y2:0, stop:0.0199005 rgba(45, 45, 45, 255), stop:0.880597 rgba(0, 0, 0, 255));")
        self.LeftMenu.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.LeftMenu.setFrameShadow(QtWidgets.QFrame.Raised)
        self.LeftMenu.setObjectName("LeftMenu")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.LeftMenu)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setSpacing(0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.Buttons = QtWidgets.QFrame(self.LeftMenu)
        self.Buttons.setMinimumSize(QtCore.QSize(80, 0))
        font = QtGui.QFont()
        font.setStyleStrategy(QtGui.QFont.PreferAntialias)
        self.Buttons.setFont(font)
        self.Buttons.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.Buttons.setStyleSheet("")
        self.Buttons.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.Buttons.setFrameShadow(QtWidgets.QFrame.Raised)
        self.Buttons.setObjectName("Buttons")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.Buttons)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setSpacing(0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.Home = QtWidgets.QPushButton(self.Buttons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Home.sizePolicy().hasHeightForWidth())
        self.Home.setSizePolicy(sizePolicy)
        self.Home.setMinimumSize(QtCore.QSize(45, 0))
        self.Home.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Martyric Personal Use Only")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.Home.setFont(font)
        self.Home.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.472, y1:0, x2:0.4669, y2:0.813, stop:0.0298507 rgba(180, 35, 22, 255), stop:0.706468 rgba(74, 74, 74, 255));\n"
"}")
        self.Home.setObjectName("Home")
        self.verticalLayout_4.addWidget(self.Home)
        self.Crypto = QtWidgets.QPushButton(self.Buttons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Crypto.sizePolicy().hasHeightForWidth())
        self.Crypto.setSizePolicy(sizePolicy)
        self.Crypto.setMinimumSize(QtCore.QSize(45, 0))
        self.Crypto.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Martyric Personal Use Only")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.Crypto.setFont(font)
        self.Crypto.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.472, y1:0, x2:0.4669, y2:0.813, stop:0.0298507 rgba(180, 35, 22, 255), stop:0.706468 rgba(74, 74, 74, 255));\n"
"}")
        self.Crypto.setObjectName("Crypto")
        self.verticalLayout_4.addWidget(self.Crypto)
        self.FileShare = QtWidgets.QPushButton(self.Buttons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.FileShare.sizePolicy().hasHeightForWidth())
        self.FileShare.setSizePolicy(sizePolicy)
        self.FileShare.setMinimumSize(QtCore.QSize(45, 0))
        self.FileShare.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Martyric Personal Use Only")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.FileShare.setFont(font)
        self.FileShare.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.472, y1:0, x2:0.4669, y2:0.813, stop:0.0298507 rgba(180, 35, 22, 255), stop:0.706468 rgba(74, 74, 74, 255));\n"
"}")
        self.FileShare.setObjectName("FileShare")
        self.verticalLayout_4.addWidget(self.FileShare)
        self.Stego = QtWidgets.QPushButton(self.Buttons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Stego.sizePolicy().hasHeightForWidth())
        self.Stego.setSizePolicy(sizePolicy)
        self.Stego.setMinimumSize(QtCore.QSize(45, 0))
        self.Stego.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Martyric Personal Use Only")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.Stego.setFont(font)
        self.Stego.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.526726, y1:0.966, x2:0.487, y2:0, stop:0.0845771 rgba(78, 59, 58, 255), stop:0.567164 rgba(74, 74, 74, 255));\n"
"}")
        self.Stego.setObjectName("Stego")
        self.verticalLayout_4.addWidget(self.Stego)
        self.MarosMenuButton = QtWidgets.QPushButton(self.Buttons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MarosMenuButton.sizePolicy().hasHeightForWidth())
        self.MarosMenuButton.setSizePolicy(sizePolicy)
        self.MarosMenuButton.setMinimumSize(QtCore.QSize(45, 0))
        self.MarosMenuButton.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Martyric Personal Use Only")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.MarosMenuButton.setFont(font)
        self.MarosMenuButton.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.526726, y1:0.966, x2:0.487, y2:0, stop:0.0845771 rgba(78, 59, 58, 255), stop:0.567164 rgba(74, 74, 74, 255));\n"
"}")
        self.MarosMenuButton.setObjectName("MarosMenuButton")
        self.verticalLayout_4.addWidget(self.MarosMenuButton)
        self.verticalLayout_3.addWidget(self.Buttons)
        self.horizontalLayout_2.addWidget(self.LeftMenu)
        self.Pages = QtWidgets.QFrame(self.Content)
        self.Pages.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.Pages.setFrameShadow(QtWidgets.QFrame.Raised)
        self.Pages.setObjectName("Pages")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.Pages)
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_5.setSpacing(0)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.Stack = QtWidgets.QStackedWidget(self.Pages)
        self.Stack.setObjectName("Stack")
        self.HomePage = QtWidgets.QWidget()
        self.HomePage.setObjectName("HomePage")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.HomePage)
        self.verticalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_6.setSpacing(10)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.HomePageDecorations = QtWidgets.QFrame(self.HomePage)
        self.HomePageDecorations.setMinimumSize(QtCore.QSize(0, 175))
        self.HomePageDecorations.setMaximumSize(QtCore.QSize(16777215, 175))
        self.HomePageDecorations.setStyleSheet("background-color: rgba(0,0,0,0);")
        self.HomePageDecorations.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.HomePageDecorations.setFrameShadow(QtWidgets.QFrame.Raised)
        self.HomePageDecorations.setObjectName("HomePageDecorations")
        self.AppNameBig = QtWidgets.QLabel(self.HomePageDecorations)
        self.AppNameBig.setGeometry(QtCore.QRect(0, 0, 981, 111))
        font = QtGui.QFont()
        font.setFamily("Creepsville")
        font.setPointSize(45)
        font.setBold(True)
        font.setItalic(True)
        font.setUnderline(False)
        font.setWeight(75)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferAntialias)
        self.AppNameBig.setFont(font)
        self.AppNameBig.setStyleSheet("color: rgb(159, 8, 23);\n"
"background-color: rgba(0, 0, 0, 0)")
        self.AppNameBig.setAlignment(QtCore.Qt.AlignCenter)
        self.AppNameBig.setWordWrap(False)
        self.AppNameBig.setObjectName("AppNameBig")
        self.AppDesc = QtWidgets.QLabel(self.HomePageDecorations)
        self.AppDesc.setGeometry(QtCore.QRect(0, 100, 981, 41))
        font = QtGui.QFont()
        font.setFamily("CF Night of Terror PERSONAL")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(True)
        font.setWeight(50)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferAntialias)
        self.AppDesc.setFont(font)
        self.AppDesc.setStyleSheet("color: rgba(135, 42, 70, 220);")
        self.AppDesc.setAlignment(QtCore.Qt.AlignCenter)
        self.AppDesc.setObjectName("AppDesc")
        self.verticalLayout_6.addWidget(self.HomePageDecorations)
        self.PageLinks = QtWidgets.QFrame(self.HomePage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.PageLinks.sizePolicy().hasHeightForWidth())
        self.PageLinks.setSizePolicy(sizePolicy)
        self.PageLinks.setStyleSheet("background-color: rgba(0,0,0,0);")
        self.PageLinks.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.PageLinks.setFrameShadow(QtWidgets.QFrame.Raised)
        self.PageLinks.setObjectName("PageLinks")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.PageLinks)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setSpacing(0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.CryptoPageButton = QtWidgets.QPushButton(self.PageLinks)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.CryptoPageButton.sizePolicy().hasHeightForWidth())
        self.CryptoPageButton.setSizePolicy(sizePolicy)
        self.CryptoPageButton.setMinimumSize(QtCore.QSize(250, 0))
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(18)
        self.CryptoPageButton.setFont(font)
        self.CryptoPageButton.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(78, 59, 58, 231), stop:0.567164 rgba(74, 74, 74, 234));\n"
"}")
        self.CryptoPageButton.setDefault(False)
        self.CryptoPageButton.setObjectName("CryptoPageButton")
        self.horizontalLayout_3.addWidget(self.CryptoPageButton)
        self.TransferPageButton = QtWidgets.QPushButton(self.PageLinks)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.TransferPageButton.sizePolicy().hasHeightForWidth())
        self.TransferPageButton.setSizePolicy(sizePolicy)
        self.TransferPageButton.setMinimumSize(QtCore.QSize(250, 0))
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(18)
        self.TransferPageButton.setFont(font)
        self.TransferPageButton.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(78, 59, 58, 231), stop:0.567164 rgba(74, 74, 74, 234));\n"
"}")
        self.TransferPageButton.setObjectName("TransferPageButton")
        self.horizontalLayout_3.addWidget(self.TransferPageButton)
        self.StegoPageButton = QtWidgets.QPushButton(self.PageLinks)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.StegoPageButton.sizePolicy().hasHeightForWidth())
        self.StegoPageButton.setSizePolicy(sizePolicy)
        self.StegoPageButton.setMinimumSize(QtCore.QSize(250, 0))
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(18)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.StegoPageButton.setFont(font)
        self.StegoPageButton.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(78, 59, 58, 231), stop:0.567164 rgba(74, 74, 74, 234));\n"
"}")
        self.StegoPageButton.setObjectName("StegoPageButton")
        self.horizontalLayout_3.addWidget(self.StegoPageButton)
        self.MacroPageButton = QtWidgets.QPushButton(self.PageLinks)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MacroPageButton.sizePolicy().hasHeightForWidth())
        self.MacroPageButton.setSizePolicy(sizePolicy)
        self.MacroPageButton.setMinimumSize(QtCore.QSize(250, 0))
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(18)
        self.MacroPageButton.setFont(font)
        self.MacroPageButton.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(78, 59, 58, 231), stop:0.567164 rgba(74, 74, 74, 234));\n"
"}")
        self.MacroPageButton.setObjectName("MacroPageButton")
        self.horizontalLayout_3.addWidget(self.MacroPageButton)
        self.verticalLayout_6.addWidget(self.PageLinks)
        self.Stack.addWidget(self.HomePage)
        self.CryptoPage = QtWidgets.QWidget()
        self.CryptoPage.setObjectName("CryptoPage")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout(self.CryptoPage)
        self.verticalLayout_15.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_15.setSpacing(0)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.CryptoDragDropFrame = QtWidgets.QFrame(self.CryptoPage)
        self.CryptoDragDropFrame.setMinimumSize(QtCore.QSize(1000, 125))
        self.CryptoDragDropFrame.setMaximumSize(QtCore.QSize(1000, 16777215))
        self.CryptoDragDropFrame.setAcceptDrops(True)
        self.CryptoDragDropFrame.setStyleSheet("background-color: rgba(0, 0, 0, 0);")
        self.CryptoDragDropFrame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.CryptoDragDropFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.CryptoDragDropFrame.setObjectName("CryptoDragDropFrame")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.CryptoDragDropFrame)
        self.horizontalLayout_8.setContentsMargins(2, 2, 2, 0)
        self.horizontalLayout_8.setSpacing(0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.CryptoDragDrop = DragDropWidget(self.CryptoDragDropFrame)
        self.CryptoDragDrop.setAcceptDrops(True)
        self.CryptoDragDrop.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.CryptoDragDrop.setObjectName("CryptoDragDrop")
        self.verticalLayout_16 = QtWidgets.QVBoxLayout(self.CryptoDragDrop)
        self.verticalLayout_16.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_16.setSpacing(0)
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        self.CryptoDragDropLabel = QtWidgets.QLabel(self.CryptoDragDrop)
        font = QtGui.QFont()
        font.setFamily("Cabin Sketch")
        font.setPointSize(30)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferAntialias)
        self.CryptoDragDropLabel.setFont(font)
        self.CryptoDragDropLabel.setStyleSheet("border: 0px;\n"
"")
        self.CryptoDragDropLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.CryptoDragDropLabel.setObjectName("CryptoDragDropLabel")
        self.verticalLayout_16.addWidget(self.CryptoDragDropLabel)
        self.horizontalLayout_8.addWidget(self.CryptoDragDrop)
        self.verticalLayout_15.addWidget(self.CryptoDragDropFrame)
        self.CryptoFrameMiddle = QtWidgets.QFrame(self.CryptoPage)
        self.CryptoFrameMiddle.setStyleSheet("background-color: rgba(0, 0, 0, 0);")
        self.CryptoFrameMiddle.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.CryptoFrameMiddle.setFrameShadow(QtWidgets.QFrame.Raised)
        self.CryptoFrameMiddle.setObjectName("CryptoFrameMiddle")
        self.verticalLayout_17 = QtWidgets.QVBoxLayout(self.CryptoFrameMiddle)
        self.verticalLayout_17.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_17.setSpacing(0)
        self.verticalLayout_17.setObjectName("verticalLayout_17")
        self.CryptoSaveLoc = QtWidgets.QFrame(self.CryptoFrameMiddle)
        self.CryptoSaveLoc.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.CryptoSaveLoc.setFrameShadow(QtWidgets.QFrame.Raised)
        self.CryptoSaveLoc.setObjectName("CryptoSaveLoc")
        self.verticalLayout_18 = QtWidgets.QVBoxLayout(self.CryptoSaveLoc)
        self.verticalLayout_18.setContentsMargins(3, 4, 3, 4)
        self.verticalLayout_18.setSpacing(2)
        self.verticalLayout_18.setObjectName("verticalLayout_18")
        self.CryptoSaveLocBrowse = DragDropWidget(self.CryptoSaveLoc)
        self.CryptoSaveLocBrowse.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.CryptoSaveLocBrowse.setObjectName("CryptoSaveLocBrowse")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout(self.CryptoSaveLocBrowse)
        self.horizontalLayout_10.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_10.setSpacing(0)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.CryptoSaveLocBrowseL = QtWidgets.QLabel(self.CryptoSaveLocBrowse)
        self.CryptoSaveLocBrowseL.setMinimumSize(QtCore.QSize(0, 75))
        font = QtGui.QFont()
        font.setFamily("Cabin Sketch")
        font.setPointSize(30)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.CryptoSaveLocBrowseL.setFont(font)
        self.CryptoSaveLocBrowseL.setStyleSheet("border: 0px;\n"
"")
        self.CryptoSaveLocBrowseL.setAlignment(QtCore.Qt.AlignCenter)
        self.CryptoSaveLocBrowseL.setObjectName("CryptoSaveLocBrowseL")
        self.horizontalLayout_10.addWidget(self.CryptoSaveLocBrowseL)
        self.verticalLayout_18.addWidget(self.CryptoSaveLocBrowse)
        self.frame = QtWidgets.QFrame(self.CryptoSaveLoc)
        self.frame.setMaximumSize(QtCore.QSize(16777215, 38))
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.frame)
        self.horizontalLayout_9.setContentsMargins(5, 0, 8, 0)
        self.horizontalLayout_9.setSpacing(7)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.Password = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Password.sizePolicy().hasHeightForWidth())
        self.Password.setSizePolicy(sizePolicy)
        self.Password.setMinimumSize(QtCore.QSize(0, 30))
        self.Password.setMaximumSize(QtCore.QSize(16777215, 28))
        font = QtGui.QFont()
        font.setFamily("Cabin Sketch")
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.Password.setFont(font)
        self.Password.setStyleSheet("color: rgb(255, 76, 16);\n"
"background-color: qlineargradient(spread:reflect, x1:1, y1:0.579, x2:0, y2:0.477273, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 55));")
        self.Password.setText("")
        self.Password.setObjectName("Password")
        self.horizontalLayout_9.addWidget(self.Password)
        self.verticalLayout_18.addWidget(self.frame)
        self.verticalLayout_17.addWidget(self.CryptoSaveLoc)
        self.verticalLayout_15.addWidget(self.CryptoFrameMiddle)
        self.CryptoFrameBottom = QtWidgets.QFrame(self.CryptoPage)
        self.CryptoFrameBottom.setStyleSheet("background-color: rgba(0, 0, 0, 0);")
        self.CryptoFrameBottom.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.CryptoFrameBottom.setFrameShadow(QtWidgets.QFrame.Raised)
        self.CryptoFrameBottom.setObjectName("CryptoFrameBottom")
        self.verticalLayout_19 = QtWidgets.QVBoxLayout(self.CryptoFrameBottom)
        self.verticalLayout_19.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_19.setSpacing(0)
        self.verticalLayout_19.setObjectName("verticalLayout_19")
        self.SelectAlgo = QtWidgets.QFrame(self.CryptoFrameBottom)
        self.SelectAlgo.setMinimumSize(QtCore.QSize(0, 30))
        self.SelectAlgo.setMaximumSize(QtCore.QSize(1000, 30))
        self.SelectAlgo.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.SelectAlgo.setFrameShadow(QtWidgets.QFrame.Raised)
        self.SelectAlgo.setObjectName("SelectAlgo")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.SelectAlgo)
        self.horizontalLayout_11.setContentsMargins(3, 0, 7, 0)
        self.horizontalLayout_11.setSpacing(0)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.AlgoSelect = QtWidgets.QComboBox(self.SelectAlgo)
        self.AlgoSelect.setMinimumSize(QtCore.QSize(0, 25))
        font = QtGui.QFont()
        font.setFamily("Cabin Sketch")
        font.setPointSize(6)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.AlgoSelect.setFont(font)
        self.AlgoSelect.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        self.AlgoSelect.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.AlgoSelect.setStyleSheet("border: 2px solid #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.AlgoSelect.setCurrentText("")
        self.AlgoSelect.setObjectName("AlgoSelect")
        self.horizontalLayout_11.addWidget(self.AlgoSelect)
        self.verticalLayout_19.addWidget(self.SelectAlgo)
        self.CryptoButtons = QtWidgets.QFrame(self.CryptoFrameBottom)
        self.CryptoButtons.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.CryptoButtons.setFrameShadow(QtWidgets.QFrame.Raised)
        self.CryptoButtons.setObjectName("CryptoButtons")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout(self.CryptoButtons)
        self.horizontalLayout_12.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_12.setSpacing(0)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.Encrypt = QtWidgets.QPushButton(self.CryptoButtons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Encrypt.sizePolicy().hasHeightForWidth())
        self.Encrypt.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(43)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.Encrypt.setFont(font)
        self.Encrypt.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.Encrypt.setObjectName("Encrypt")
        self.horizontalLayout_12.addWidget(self.Encrypt)
        self.Decrypt = QtWidgets.QPushButton(self.CryptoButtons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Decrypt.sizePolicy().hasHeightForWidth())
        self.Decrypt.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(43)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.Decrypt.setFont(font)
        self.Decrypt.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.Decrypt.setObjectName("Decrypt")
        self.horizontalLayout_12.addWidget(self.Decrypt)
        self.verticalLayout_19.addWidget(self.CryptoButtons)
        self.verticalLayout_15.addWidget(self.CryptoFrameBottom)
        self.Stack.addWidget(self.CryptoPage)
        self.TransferPage = QtWidgets.QWidget()
        self.TransferPage.setObjectName("TransferPage")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.TransferPage)
        self.verticalLayout_12.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_12.setSpacing(0)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.AddFileTransfer = QtWidgets.QFrame(self.TransferPage)
        self.AddFileTransfer.setStyleSheet("background-color: rgba(0, 0, 0, 0);\n"
"")
        self.AddFileTransfer.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.AddFileTransfer.setFrameShadow(QtWidgets.QFrame.Raised)
        self.AddFileTransfer.setObjectName("AddFileTransfer")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.AddFileTransfer)
        self.horizontalLayout_5.setContentsMargins(4, 2, 4, 0)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.DragDropTransfer = DragDropWidget(self.AddFileTransfer)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DragDropTransfer.sizePolicy().hasHeightForWidth())
        self.DragDropTransfer.setSizePolicy(sizePolicy)
        self.DragDropTransfer.setMinimumSize(QtCore.QSize(990, 176))
        self.DragDropTransfer.setAcceptDrops(True)
        self.DragDropTransfer.setObjectName("DragDropTransfer")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.DragDropTransfer)
        self.horizontalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_6.setSpacing(0)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.DragDropLabelTransfer = QtWidgets.QLabel(self.DragDropTransfer)
        self.DragDropLabelTransfer.setMaximumSize(QtCore.QSize(992, 165))
        font = QtGui.QFont()
        font.setFamily("DEADLY KILLERS DEMO")
        font.setPointSize(30)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.DragDropLabelTransfer.setFont(font)
        self.DragDropLabelTransfer.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.DragDropLabelTransfer.setAlignment(QtCore.Qt.AlignCenter)
        self.DragDropLabelTransfer.setObjectName("DragDropLabelTransfer")
        self.horizontalLayout_6.addWidget(self.DragDropLabelTransfer)
        self.horizontalLayout_5.addWidget(self.DragDropTransfer)
        self.verticalLayout_12.addWidget(self.AddFileTransfer)
        self.Url_ButtonTransfer = QtWidgets.QFrame(self.TransferPage)
        self.Url_ButtonTransfer.setStyleSheet("background-color: rgba(0, 0, 0, 0);\n"
"")
        self.Url_ButtonTransfer.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.Url_ButtonTransfer.setFrameShadow(QtWidgets.QFrame.Raised)
        self.Url_ButtonTransfer.setObjectName("Url_ButtonTransfer")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.Url_ButtonTransfer)
        self.verticalLayout_13.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_13.setSpacing(0)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.UrlTransfer = QtWidgets.QFrame(self.Url_ButtonTransfer)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.UrlTransfer.sizePolicy().hasHeightForWidth())
        self.UrlTransfer.setSizePolicy(sizePolicy)
        self.UrlTransfer.setMaximumSize(QtCore.QSize(1000, 46))
        self.UrlTransfer.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.UrlTransfer.setFrameShadow(QtWidgets.QFrame.Raised)
        self.UrlTransfer.setObjectName("UrlTransfer")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.UrlTransfer)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.UrlLabel = QtWidgets.QLabel(self.UrlTransfer)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.UrlLabel.sizePolicy().hasHeightForWidth())
        self.UrlLabel.setSizePolicy(sizePolicy)
        self.UrlLabel.setMinimumSize(QtCore.QSize(0, 31))
        self.UrlLabel.setMaximumSize(QtCore.QSize(38, 50))
        font = QtGui.QFont()
        font.setFamily("DEADLY KILLERS DEMO")
        font.setPointSize(12)
        font.setBold(True)
        font.setWeight(75)
        self.UrlLabel.setFont(font)
        self.UrlLabel.setStyleSheet("color: rgb(211, 113, 27);")
        self.UrlLabel.setObjectName("UrlLabel")
        self.horizontalLayout_7.addWidget(self.UrlLabel)
        self.Url = QtWidgets.QLineEdit(self.UrlTransfer)
        self.Url.setMinimumSize(QtCore.QSize(0, 32))
        self.Url.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Courgette")
        font.setPointSize(11)
        self.Url.setFont(font)
        self.Url.setStyleSheet("color: rgb(255, 76, 16);\n"
"background-color: qlineargradient(spread:reflect, x1:1, y1:0.579, x2:0, y2:0.477273, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 55));")
        self.Url.setInputMask("")
        self.Url.setObjectName("Url")
        self.horizontalLayout_7.addWidget(self.Url)
        self.verticalLayout_13.addWidget(self.UrlTransfer)
        self.ButtonTransferFrame = QtWidgets.QFrame(self.Url_ButtonTransfer)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.ButtonTransferFrame.setFont(font)
        self.ButtonTransferFrame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.ButtonTransferFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.ButtonTransferFrame.setObjectName("ButtonTransferFrame")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.ButtonTransferFrame)
        self.verticalLayout_14.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_14.setSpacing(0)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.ButtonTransfer = QtWidgets.QPushButton(self.ButtonTransferFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ButtonTransfer.sizePolicy().hasHeightForWidth())
        self.ButtonTransfer.setSizePolicy(sizePolicy)
        self.ButtonTransfer.setMinimumSize(QtCore.QSize(998, 0))
        self.ButtonTransfer.setMaximumSize(QtCore.QSize(998, 16777215))
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(74)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.ButtonTransfer.setFont(font)
        self.ButtonTransfer.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.ButtonTransfer.setObjectName("ButtonTransfer")
        self.verticalLayout_14.addWidget(self.ButtonTransfer)
        self.verticalLayout_13.addWidget(self.ButtonTransferFrame)
        self.verticalLayout_12.addWidget(self.Url_ButtonTransfer)
        self.Stack.addWidget(self.TransferPage)
        self.StegoPage = QtWidgets.QWidget()
        self.StegoPage.setObjectName("StegoPage")
        self.verticalLayout_20 = QtWidgets.QVBoxLayout(self.StegoPage)
        self.verticalLayout_20.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_20.setSpacing(0)
        self.verticalLayout_20.setObjectName("verticalLayout_20")
        self.StegoPagesFrame = QtWidgets.QFrame(self.StegoPage)
        self.StegoPagesFrame.setStyleSheet("background-color: rgba(0, 0, 0, 0);\n"
"")
        self.StegoPagesFrame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.StegoPagesFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.StegoPagesFrame.setObjectName("StegoPagesFrame")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.StegoPagesFrame)
        self.horizontalLayout_13.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_13.setSpacing(0)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.StegoPage_2 = QtWidgets.QStackedWidget(self.StegoPagesFrame)
        self.StegoPage_2.setObjectName("StegoPage_2")
        self.StegoOptions = QtWidgets.QWidget()
        self.StegoOptions.setObjectName("StegoOptions")
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout(self.StegoOptions)
        self.horizontalLayout_14.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.StegoMainButtomFrame = QtWidgets.QFrame(self.StegoOptions)
        self.StegoMainButtomFrame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.StegoMainButtomFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.StegoMainButtomFrame.setObjectName("StegoMainButtomFrame")
        self.verticalLayout_21 = QtWidgets.QVBoxLayout(self.StegoMainButtomFrame)
        self.verticalLayout_21.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_21.setObjectName("verticalLayout_21")
        self.HideButton = QtWidgets.QPushButton(self.StegoMainButtomFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.HideButton.sizePolicy().hasHeightForWidth())
        self.HideButton.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(65)
        self.HideButton.setFont(font)
        self.HideButton.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.HideButton.setObjectName("HideButton")
        self.verticalLayout_21.addWidget(self.HideButton)
        self.RecoverButton = QtWidgets.QPushButton(self.StegoMainButtomFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.RecoverButton.sizePolicy().hasHeightForWidth())
        self.RecoverButton.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(49)
        self.RecoverButton.setFont(font)
        self.RecoverButton.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.RecoverButton.setObjectName("RecoverButton")
        self.verticalLayout_21.addWidget(self.RecoverButton)
        self.horizontalLayout_14.addWidget(self.StegoMainButtomFrame)
        self.StegoPage_2.addWidget(self.StegoOptions)
        self.Hide = QtWidgets.QWidget()
        self.Hide.setObjectName("Hide")
        self.verticalLayout_22 = QtWidgets.QVBoxLayout(self.Hide)
        self.verticalLayout_22.setContentsMargins(2, 0, 2, 0)
        self.verticalLayout_22.setSpacing(4)
        self.verticalLayout_22.setObjectName("verticalLayout_22")
        self.Infile = QtWidgets.QFrame(self.Hide)
        self.Infile.setMaximumSize(QtCore.QSize(16777215, 90))
        self.Infile.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.Infile.setFrameShadow(QtWidgets.QFrame.Raised)
        self.Infile.setObjectName("Infile")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.Infile)
        self.horizontalLayout_15.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_15.setSpacing(0)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.InfileDragDrop = DragDropWidget(self.Infile)
        self.InfileDragDrop.setAcceptDrops(True)
        self.InfileDragDrop.setObjectName("InfileDragDrop")
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout(self.InfileDragDrop)
        self.horizontalLayout_16.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_16.setSpacing(0)
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.InfileDragDropLabel = QtWidgets.QLabel(self.InfileDragDrop)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(22)
        font.setItalic(True)
        self.InfileDragDropLabel.setFont(font)
        self.InfileDragDropLabel.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.InfileDragDropLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.InfileDragDropLabel.setObjectName("InfileDragDropLabel")
        self.horizontalLayout_16.addWidget(self.InfileDragDropLabel)
        self.horizontalLayout_15.addWidget(self.InfileDragDrop)
        self.verticalLayout_22.addWidget(self.Infile)
        self.Datafile = QtWidgets.QFrame(self.Hide)
        self.Datafile.setMaximumSize(QtCore.QSize(16777215, 87))
        self.Datafile.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.Datafile.setFrameShadow(QtWidgets.QFrame.Raised)
        self.Datafile.setObjectName("Datafile")
        self.DatafileDragDrop = DragDropWidget(self.Datafile)
        self.DatafileDragDrop.setGeometry(QtCore.QRect(0, 0, 996, 87))
        self.DatafileDragDrop.setAcceptDrops(True)
        self.DatafileDragDrop.setObjectName("DatafileDragDrop")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout(self.DatafileDragDrop)
        self.horizontalLayout_17.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_17.setSpacing(0)
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.DatafileDragDropLabel = QtWidgets.QLabel(self.DatafileDragDrop)
        self.DatafileDragDropLabel.setMinimumSize(QtCore.QSize(0, 0))
        self.DatafileDragDropLabel.setMaximumSize(QtCore.QSize(16777215, 84))
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(22)
        font.setItalic(True)
        self.DatafileDragDropLabel.setFont(font)
        self.DatafileDragDropLabel.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.DatafileDragDropLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.DatafileDragDropLabel.setObjectName("DatafileDragDropLabel")
        self.horizontalLayout_17.addWidget(self.DatafileDragDropLabel)
        self.verticalLayout_22.addWidget(self.Datafile)
        self.BrowseSaveLocationStego = QtWidgets.QFrame(self.Hide)
        self.BrowseSaveLocationStego.setMaximumSize(QtCore.QSize(16777215, 50))
        self.BrowseSaveLocationStego.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.BrowseSaveLocationStego.setFrameShadow(QtWidgets.QFrame.Raised)
        self.BrowseSaveLocationStego.setObjectName("BrowseSaveLocationStego")
        self.SaveLocBrowseStego = DragDropWidget(self.BrowseSaveLocationStego)
        self.SaveLocBrowseStego.setGeometry(QtCore.QRect(0, 0, 996, 50))
        self.SaveLocBrowseStego.setMaximumSize(QtCore.QSize(16777215, 50))
        self.SaveLocBrowseStego.setAcceptDrops(True)
        self.SaveLocBrowseStego.setObjectName("SaveLocBrowseStego")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self.SaveLocBrowseStego)
        self.horizontalLayout_18.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_18.setSpacing(0)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.SaveLocBrowseStegoLabel = QtWidgets.QLabel(self.SaveLocBrowseStego)
        self.SaveLocBrowseStegoLabel.setMaximumSize(QtCore.QSize(16777215, 50))
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(22)
        font.setItalic(True)
        self.SaveLocBrowseStegoLabel.setFont(font)
        self.SaveLocBrowseStegoLabel.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.SaveLocBrowseStegoLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.SaveLocBrowseStegoLabel.setObjectName("SaveLocBrowseStegoLabel")
        self.horizontalLayout_18.addWidget(self.SaveLocBrowseStegoLabel)
        self.verticalLayout_22.addWidget(self.BrowseSaveLocationStego)
        self.ButtonsStego = QtWidgets.QFrame(self.Hide)
        self.ButtonsStego.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.ButtonsStego.setFrameShadow(QtWidgets.QFrame.Raised)
        self.ButtonsStego.setObjectName("ButtonsStego")
        self.verticalLayout_23 = QtWidgets.QVBoxLayout(self.ButtonsStego)
        self.verticalLayout_23.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_23.setSpacing(0)
        self.verticalLayout_23.setObjectName("verticalLayout_23")
        self.LSBFrame = QtWidgets.QFrame(self.ButtonsStego)
        self.LSBFrame.setMinimumSize(QtCore.QSize(0, 0))
        self.LSBFrame.setMaximumSize(QtCore.QSize(16777215, 35))
        self.LSBFrame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.LSBFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.LSBFrame.setObjectName("LSBFrame")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout(self.LSBFrame)
        self.horizontalLayout_19.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_19.setSpacing(0)
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.lsb = QtWidgets.QLineEdit(self.LSBFrame)
        self.lsb.setMinimumSize(QtCore.QSize(0, 35))
        self.lsb.setMaximumSize(QtCore.QSize(16777215, 35))
        font = QtGui.QFont()
        font.setFamily("Courgette")
        font.setPointSize(11)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.lsb.setFont(font)
        self.lsb.setStyleSheet("color: rgb(255, 76, 16);\n"
"background-color: qlineargradient(spread:reflect, x1:1, y1:0.579, x2:0, y2:0.477273, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 55));")
        self.lsb.setAlignment(QtCore.Qt.AlignCenter)
        self.lsb.setObjectName("lsb")
        self.horizontalLayout_19.addWidget(self.lsb)
        self.verticalLayout_23.addWidget(self.LSBFrame)
        self.BtnStegoFrame = QtWidgets.QFrame(self.ButtonsStego)
        self.BtnStegoFrame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.BtnStegoFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.BtnStegoFrame.setObjectName("BtnStegoFrame")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout(self.BtnStegoFrame)
        self.horizontalLayout_20.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_20.setSpacing(0)
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.HideBtn = QtWidgets.QPushButton(self.BtnStegoFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.HideBtn.sizePolicy().hasHeightForWidth())
        self.HideBtn.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(30)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.HideBtn.setFont(font)
        self.HideBtn.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.HideBtn.setObjectName("HideBtn")
        self.horizontalLayout_20.addWidget(self.HideBtn)
        self.verticalLayout_23.addWidget(self.BtnStegoFrame)
        self.verticalLayout_22.addWidget(self.ButtonsStego)
        self.StegoPage_2.addWidget(self.Hide)
        self.Recover = QtWidgets.QWidget()
        self.Recover.setObjectName("Recover")
        self.verticalLayout_24 = QtWidgets.QVBoxLayout(self.Recover)
        self.verticalLayout_24.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_24.setSpacing(0)
        self.verticalLayout_24.setObjectName("verticalLayout_24")
        self.InfileRec = QtWidgets.QFrame(self.Recover)
        self.InfileRec.setMinimumSize(QtCore.QSize(0, 115))
        self.InfileRec.setMaximumSize(QtCore.QSize(16777215, 115))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.InfileRec.setFont(font)
        self.InfileRec.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.InfileRec.setFrameShadow(QtWidgets.QFrame.Raised)
        self.InfileRec.setObjectName("InfileRec")
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout(self.InfileRec)
        self.horizontalLayout_21.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_21.setSpacing(0)
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.InfileRedDragDrop = DragDropWidget(self.InfileRec)
        self.InfileRedDragDrop.setObjectName("InfileRedDragDrop")
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout(self.InfileRedDragDrop)
        self.horizontalLayout_22.setContentsMargins(3, 3, 4, 3)
        self.horizontalLayout_22.setSpacing(0)
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self.InfileRecLabel = QtWidgets.QLabel(self.InfileRedDragDrop)
        self.InfileRecLabel.setMinimumSize(QtCore.QSize(0, 109))
        self.InfileRecLabel.setMaximumSize(QtCore.QSize(16777215, 109))
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(31)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.InfileRecLabel.setFont(font)
        self.InfileRecLabel.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.InfileRecLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.InfileRecLabel.setObjectName("InfileRecLabel")
        self.horizontalLayout_22.addWidget(self.InfileRecLabel)
        self.horizontalLayout_21.addWidget(self.InfileRedDragDrop)
        self.verticalLayout_24.addWidget(self.InfileRec)
        self.OutfileRec = QtWidgets.QFrame(self.Recover)
        self.OutfileRec.setMinimumSize(QtCore.QSize(0, 84))
        self.OutfileRec.setMaximumSize(QtCore.QSize(16777215, 84))
        self.OutfileRec.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.OutfileRec.setFrameShadow(QtWidgets.QFrame.Raised)
        self.OutfileRec.setObjectName("OutfileRec")
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout(self.OutfileRec)
        self.horizontalLayout_23.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_23.setSpacing(0)
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        self.OutfileRecBrowse = DragDropWidget(self.OutfileRec)
        self.OutfileRecBrowse.setObjectName("OutfileRecBrowse")
        self.horizontalLayout_24 = QtWidgets.QHBoxLayout(self.OutfileRecBrowse)
        self.horizontalLayout_24.setContentsMargins(3, 0, 3, 4)
        self.horizontalLayout_24.setSpacing(0)
        self.horizontalLayout_24.setObjectName("horizontalLayout_24")
        self.OutfileRecLabel = QtWidgets.QLabel(self.OutfileRecBrowse)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(32)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.OutfileRecLabel.setFont(font)
        self.OutfileRecLabel.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.OutfileRecLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.OutfileRecLabel.setObjectName("OutfileRecLabel")
        self.horizontalLayout_24.addWidget(self.OutfileRecLabel)
        self.horizontalLayout_23.addWidget(self.OutfileRecBrowse)
        self.verticalLayout_24.addWidget(self.OutfileRec)
        self.LSBNB = QtWidgets.QFrame(self.Recover)
        self.LSBNB.setMinimumSize(QtCore.QSize(0, 72))
        self.LSBNB.setMaximumSize(QtCore.QSize(16777215, 72))
        self.LSBNB.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.LSBNB.setFrameShadow(QtWidgets.QFrame.Raised)
        self.LSBNB.setObjectName("LSBNB")
        self.horizontalLayout_25 = QtWidgets.QHBoxLayout(self.LSBNB)
        self.horizontalLayout_25.setContentsMargins(0, 0, 0, -1)
        self.horizontalLayout_25.setSpacing(0)
        self.horizontalLayout_25.setObjectName("horizontalLayout_25")
        self.Labels = QtWidgets.QFrame(self.LSBNB)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Labels.sizePolicy().hasHeightForWidth())
        self.Labels.setSizePolicy(sizePolicy)
        self.Labels.setMinimumSize(QtCore.QSize(143, 0))
        self.Labels.setMaximumSize(QtCore.QSize(140, 16777215))
        self.Labels.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.Labels.setFrameShadow(QtWidgets.QFrame.Raised)
        self.Labels.setObjectName("Labels")
        self.verticalLayout_25 = QtWidgets.QVBoxLayout(self.Labels)
        self.verticalLayout_25.setContentsMargins(5, 0, 0, 0)
        self.verticalLayout_25.setSpacing(0)
        self.verticalLayout_25.setObjectName("verticalLayout_25")
        self.LSBLabel = QtWidgets.QLabel(self.Labels)
        font = QtGui.QFont()
        font.setFamily("Lemon")
        font.setBold(False)
        font.setItalic(True)
        font.setWeight(50)
        self.LSBLabel.setFont(font)
        self.LSBLabel.setStyleSheet("color: rgb(211, 113, 27);")
        self.LSBLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.LSBLabel.setIndent(6)
        self.LSBLabel.setObjectName("LSBLabel")
        self.verticalLayout_25.addWidget(self.LSBLabel)
        self.NBLabel = QtWidgets.QLabel(self.Labels)
        font = QtGui.QFont()
        font.setFamily("Lemon")
        font.setBold(False)
        font.setItalic(True)
        font.setWeight(50)
        self.NBLabel.setFont(font)
        self.NBLabel.setStyleSheet("color: rgb(211, 113, 27);")
        self.NBLabel.setObjectName("NBLabel")
        self.verticalLayout_25.addWidget(self.NBLabel)
        self.horizontalLayout_25.addWidget(self.Labels)
        self.InputBoxes = QtWidgets.QFrame(self.LSBNB)
        self.InputBoxes.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.InputBoxes.setFrameShadow(QtWidgets.QFrame.Raised)
        self.InputBoxes.setObjectName("InputBoxes")
        self.verticalLayout_26 = QtWidgets.QVBoxLayout(self.InputBoxes)
        self.verticalLayout_26.setContentsMargins(0, 0, 0, 3)
        self.verticalLayout_26.setObjectName("verticalLayout_26")
        self.LSB = QtWidgets.QLineEdit(self.InputBoxes)
        self.LSB.setMinimumSize(QtCore.QSize(0, 28))
        self.LSB.setMaximumSize(QtCore.QSize(16777215, 30))
        font = QtGui.QFont()
        font.setFamily("Courgette")
        font.setPointSize(9)
        self.LSB.setFont(font)
        self.LSB.setStyleSheet("color: rgb(255, 76, 16);\n"
"background-color: qlineargradient(spread:reflect, x1:1, y1:0.579, x2:0, y2:0.477273, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 55));")
        self.LSB.setAlignment(QtCore.Qt.AlignCenter)
        self.LSB.setObjectName("LSB")
        self.verticalLayout_26.addWidget(self.LSB)
        self.NBytes = QtWidgets.QLineEdit(self.InputBoxes)
        self.NBytes.setMinimumSize(QtCore.QSize(0, 28))
        self.NBytes.setMaximumSize(QtCore.QSize(16777215, 30))
        font = QtGui.QFont()
        font.setFamily("Courgette")
        font.setPointSize(9)
        font.setItalic(False)
        self.NBytes.setFont(font)
        self.NBytes.setStyleSheet("color: rgb(255, 76, 16);\n"
"background-color: qlineargradient(spread:reflect, x1:1, y1:0.579, x2:0, y2:0.477273, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 55));")
        self.NBytes.setAlignment(QtCore.Qt.AlignCenter)
        self.NBytes.setObjectName("NBytes")
        self.verticalLayout_26.addWidget(self.NBytes)
        self.horizontalLayout_25.addWidget(self.InputBoxes)
        self.verticalLayout_24.addWidget(self.LSBNB)
        self.RecButtonFrame = QtWidgets.QFrame(self.Recover)
        self.RecButtonFrame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.RecButtonFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.RecButtonFrame.setObjectName("RecButtonFrame")
        self.horizontalLayout_26 = QtWidgets.QHBoxLayout(self.RecButtonFrame)
        self.horizontalLayout_26.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_26.setObjectName("horizontalLayout_26")
        self.RecButton = QtWidgets.QPushButton(self.RecButtonFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.RecButton.sizePolicy().hasHeightForWidth())
        self.RecButton.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(50)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.RecButton.setFont(font)
        self.RecButton.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.RecButton.setObjectName("RecButton")
        self.horizontalLayout_26.addWidget(self.RecButton)
        self.verticalLayout_24.addWidget(self.RecButtonFrame)
        self.StegoPage_2.addWidget(self.Recover)
        self.horizontalLayout_13.addWidget(self.StegoPage_2)
        self.verticalLayout_20.addWidget(self.StegoPagesFrame)
        self.Stack.addWidget(self.StegoPage)
        self.MacroPage = QtWidgets.QWidget()
        self.MacroPage.setObjectName("MacroPage")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.MacroPage)
        self.verticalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_7.setSpacing(0)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.stackedWidget = QtWidgets.QStackedWidget(self.MacroPage)
        self.stackedWidget.setObjectName("stackedWidget")
        self.MacrosPage = QtWidgets.QWidget()
        self.MacrosPage.setObjectName("MacrosPage")
        self.gridLayout = QtWidgets.QGridLayout(self.MacrosPage)
        self.gridLayout.setObjectName("gridLayout")
        self.MoreComingSoon = QtWidgets.QLabel(self.MacrosPage)
        font = QtGui.QFont()
        font.setFamily("Mongolian Baiti")
        font.setPointSize(14)
        font.setItalic(True)
        self.MoreComingSoon.setFont(font)
        self.MoreComingSoon.setStyleSheet("\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;")
        self.MoreComingSoon.setAlignment(QtCore.Qt.AlignCenter)
        self.MoreComingSoon.setObjectName("MoreComingSoon")
        self.gridLayout.addWidget(self.MoreComingSoon, 1, 0, 1, 2)
        self.ES = QtWidgets.QFrame(self.MacrosPage)
        self.ES.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.ES.setFrameShadow(QtWidgets.QFrame.Raised)
        self.ES.setObjectName("ES")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.ES)
        self.horizontalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_4.setSpacing(0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.EncSteg = QtWidgets.QPushButton(self.ES)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.EncSteg.sizePolicy().hasHeightForWidth())
        self.EncSteg.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(45)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.EncSteg.setFont(font)
        self.EncSteg.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.EncSteg.setObjectName("EncSteg")
        self.horizontalLayout_4.addWidget(self.EncSteg)
        self.gridLayout.addWidget(self.ES, 0, 0, 1, 1)
        self.SE = QtWidgets.QFrame(self.MacrosPage)
        self.SE.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.SE.setFrameShadow(QtWidgets.QFrame.Raised)
        self.SE.setObjectName("SE")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.SE)
        self.verticalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_8.setSpacing(0)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.StegEnc = QtWidgets.QPushButton(self.SE)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.StegEnc.sizePolicy().hasHeightForWidth())
        self.StegEnc.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(45)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.StegEnc.setFont(font)
        self.StegEnc.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.StegEnc.setObjectName("StegEnc")
        self.verticalLayout_8.addWidget(self.StegEnc)
        self.gridLayout.addWidget(self.SE, 0, 1, 1, 1)
        self.stackedWidget.addWidget(self.MacrosPage)
        self.EncryptStegoPage = QtWidgets.QWidget()
        self.EncryptStegoPage.setObjectName("EncryptStegoPage")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.EncryptStegoPage)
        self.verticalLayout_9.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_9.setSpacing(0)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.MacroInfile = QtWidgets.QFrame(self.EncryptStegoPage)
        self.MacroInfile.setMinimumSize(QtCore.QSize(0, 90))
        self.MacroInfile.setMaximumSize(QtCore.QSize(16777215, 90))
        self.MacroInfile.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.MacroInfile.setFrameShadow(QtWidgets.QFrame.Raised)
        self.MacroInfile.setObjectName("MacroInfile")
        self.horizontalLayout_27 = QtWidgets.QHBoxLayout(self.MacroInfile)
        self.horizontalLayout_27.setContentsMargins(4, 0, 4, 0)
        self.horizontalLayout_27.setSpacing(0)
        self.horizontalLayout_27.setObjectName("horizontalLayout_27")
        self.MInfileDragDrop = DragDropWidget(self.MacroInfile)
        self.MInfileDragDrop.setAcceptDrops(True)
        self.MInfileDragDrop.setObjectName("MInfileDragDrop")
        self.horizontalLayout_28 = QtWidgets.QHBoxLayout(self.MInfileDragDrop)
        self.horizontalLayout_28.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_28.setSpacing(0)
        self.horizontalLayout_28.setObjectName("horizontalLayout_28")
        self.MInfileLabel = QtWidgets.QLabel(self.MInfileDragDrop)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(25)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.MInfileLabel.setFont(font)
        self.MInfileLabel.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.MInfileLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.MInfileLabel.setObjectName("MInfileLabel")
        self.horizontalLayout_28.addWidget(self.MInfileLabel)
        self.horizontalLayout_27.addWidget(self.MInfileDragDrop)
        self.verticalLayout_9.addWidget(self.MacroInfile)
        self.MacroDatafile = QtWidgets.QFrame(self.EncryptStegoPage)
        self.MacroDatafile.setMinimumSize(QtCore.QSize(0, 93))
        self.MacroDatafile.setMaximumSize(QtCore.QSize(16777215, 93))
        self.MacroDatafile.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.MacroDatafile.setFrameShadow(QtWidgets.QFrame.Raised)
        self.MacroDatafile.setObjectName("MacroDatafile")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.MacroDatafile)
        self.verticalLayout_10.setContentsMargins(4, 0, 4, 0)
        self.verticalLayout_10.setSpacing(0)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.MDatafileDragDrop = DragDropWidget(self.MacroDatafile)
        self.MDatafileDragDrop.setObjectName("MDatafileDragDrop")
        self.horizontalLayout_30 = QtWidgets.QHBoxLayout(self.MDatafileDragDrop)
        self.horizontalLayout_30.setContentsMargins(0, 3, 0, 0)
        self.horizontalLayout_30.setSpacing(0)
        self.horizontalLayout_30.setObjectName("horizontalLayout_30")
        self.MDatafileLabel = QtWidgets.QLabel(self.MDatafileDragDrop)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(25)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.MDatafileLabel.setFont(font)
        self.MDatafileLabel.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.MDatafileLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.MDatafileLabel.setObjectName("MDatafileLabel")
        self.horizontalLayout_30.addWidget(self.MDatafileLabel)
        self.verticalLayout_10.addWidget(self.MDatafileDragDrop)
        self.verticalLayout_9.addWidget(self.MacroDatafile)
        self.SaveLocation = QtWidgets.QFrame(self.EncryptStegoPage)
        self.SaveLocation.setMinimumSize(QtCore.QSize(0, 57))
        self.SaveLocation.setMaximumSize(QtCore.QSize(16777215, 57))
        font = QtGui.QFont()
        font.setPointSize(1)
        self.SaveLocation.setFont(font)
        self.SaveLocation.setStyleSheet("")
        self.SaveLocation.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.SaveLocation.setFrameShadow(QtWidgets.QFrame.Raised)
        self.SaveLocation.setObjectName("SaveLocation")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.SaveLocation)
        self.verticalLayout_11.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_11.setSpacing(0)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.SaveLocationBrowse = DragDropWidget(self.SaveLocation)
        self.SaveLocationBrowse.setObjectName("SaveLocationBrowse")
        self.horizontalLayout_31 = QtWidgets.QHBoxLayout(self.SaveLocationBrowse)
        self.horizontalLayout_31.setContentsMargins(3, 2, 3, 0)
        self.horizontalLayout_31.setSpacing(0)
        self.horizontalLayout_31.setObjectName("horizontalLayout_31")
        self.SaveLocationBrowseLabel = QtWidgets.QLabel(self.SaveLocationBrowse)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(25)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.SaveLocationBrowseLabel.setFont(font)
        self.SaveLocationBrowseLabel.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.SaveLocationBrowseLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.SaveLocationBrowseLabel.setObjectName("SaveLocationBrowseLabel")
        self.horizontalLayout_31.addWidget(self.SaveLocationBrowseLabel)
        self.verticalLayout_11.addWidget(self.SaveLocationBrowse)
        self.verticalLayout_9.addWidget(self.SaveLocation)
        self.LSBNbytes = QtWidgets.QFrame(self.EncryptStegoPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.LSBNbytes.sizePolicy().hasHeightForWidth())
        self.LSBNbytes.setSizePolicy(sizePolicy)
        self.LSBNbytes.setMinimumSize(QtCore.QSize(0, 60))
        self.LSBNbytes.setMaximumSize(QtCore.QSize(16777215, 60))
        self.LSBNbytes.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.LSBNbytes.setFrameShadow(QtWidgets.QFrame.Raised)
        self.LSBNbytes.setObjectName("LSBNbytes")
        self.horizontalLayout_32 = QtWidgets.QHBoxLayout(self.LSBNbytes)
        self.horizontalLayout_32.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_32.setSpacing(0)
        self.horizontalLayout_32.setObjectName("horizontalLayout_32")
        self.Labels_2 = QtWidgets.QFrame(self.LSBNbytes)
        self.Labels_2.setMinimumSize(QtCore.QSize(0, 60))
        self.Labels_2.setMaximumSize(QtCore.QSize(164, 60))
        self.Labels_2.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.Labels_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.Labels_2.setObjectName("Labels_2")
        self.verticalLayout_27 = QtWidgets.QVBoxLayout(self.Labels_2)
        self.verticalLayout_27.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_27.setSpacing(0)
        self.verticalLayout_27.setObjectName("verticalLayout_27")
        self.LSBLabel_2 = QtWidgets.QLabel(self.Labels_2)
        font = QtGui.QFont()
        font.setFamily("Lemon")
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.LSBLabel_2.setFont(font)
        self.LSBLabel_2.setStyleSheet("color: rgb(211, 113, 27);")
        self.LSBLabel_2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.LSBLabel_2.setIndent(5)
        self.LSBLabel_2.setObjectName("LSBLabel_2")
        self.verticalLayout_27.addWidget(self.LSBLabel_2)
        self.NBytesLabel = QtWidgets.QLabel(self.Labels_2)
        font = QtGui.QFont()
        font.setFamily("Lemon")
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.NBytesLabel.setFont(font)
        self.NBytesLabel.setStyleSheet("color: rgb(211, 113, 27);")
        self.NBytesLabel.setObjectName("NBytesLabel")
        self.verticalLayout_27.addWidget(self.NBytesLabel)
        self.horizontalLayout_32.addWidget(self.Labels_2)
        self.Inputs = QtWidgets.QFrame(self.LSBNbytes)
        self.Inputs.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.Inputs.setFrameShadow(QtWidgets.QFrame.Raised)
        self.Inputs.setObjectName("Inputs")
        self.verticalLayout_28 = QtWidgets.QVBoxLayout(self.Inputs)
        self.verticalLayout_28.setContentsMargins(0, 0, 4, 0)
        self.verticalLayout_28.setSpacing(2)
        self.verticalLayout_28.setObjectName("verticalLayout_28")
        self.LSBInput = QtWidgets.QLineEdit(self.Inputs)
        font = QtGui.QFont()
        font.setFamily("Courgette")
        font.setPointSize(9)
        self.LSBInput.setFont(font)
        self.LSBInput.setStyleSheet("color: rgb(255, 76, 16);\n"
"background-color: qlineargradient(spread:reflect, x1:1, y1:0.579, x2:0, y2:0.477273, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 55));")
        self.LSBInput.setAlignment(QtCore.Qt.AlignCenter)
        self.LSBInput.setObjectName("LSBInput")
        self.verticalLayout_28.addWidget(self.LSBInput)
        self.NBytesInput = QtWidgets.QLineEdit(self.Inputs)
        font = QtGui.QFont()
        font.setFamily("Courgette")
        font.setPointSize(9)
        self.NBytesInput.setFont(font)
        self.NBytesInput.setStyleSheet("color: rgb(255, 76, 16);\n"
"background-color: qlineargradient(spread:reflect, x1:1, y1:0.579, x2:0, y2:0.477273, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 55));")
        self.NBytesInput.setAlignment(QtCore.Qt.AlignCenter)
        self.NBytesInput.setObjectName("NBytesInput")
        self.verticalLayout_28.addWidget(self.NBytesInput)
        self.horizontalLayout_32.addWidget(self.Inputs)
        self.verticalLayout_9.addWidget(self.LSBNbytes)
        self.ButtonsM1 = QtWidgets.QFrame(self.EncryptStegoPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ButtonsM1.sizePolicy().hasHeightForWidth())
        self.ButtonsM1.setSizePolicy(sizePolicy)
        self.ButtonsM1.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.ButtonsM1.setFrameShadow(QtWidgets.QFrame.Raised)
        self.ButtonsM1.setObjectName("ButtonsM1")
        self.horizontalLayout_33 = QtWidgets.QHBoxLayout(self.ButtonsM1)
        self.horizontalLayout_33.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_33.setSpacing(0)
        self.horizontalLayout_33.setObjectName("horizontalLayout_33")
        self.Forward = QtWidgets.QPushButton(self.ButtonsM1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Forward.sizePolicy().hasHeightForWidth())
        self.Forward.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(22)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.Forward.setFont(font)
        self.Forward.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.Forward.setObjectName("Forward")
        self.horizontalLayout_33.addWidget(self.Forward)
        self.Backward = QtWidgets.QPushButton(self.ButtonsM1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Backward.sizePolicy().hasHeightForWidth())
        self.Backward.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(22)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.Backward.setFont(font)
        self.Backward.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.Backward.setObjectName("Backward")
        self.horizontalLayout_33.addWidget(self.Backward)
        self.verticalLayout_9.addWidget(self.ButtonsM1)
        self.stackedWidget.addWidget(self.EncryptStegoPage)
        self.StegoEncryptPage = QtWidgets.QWidget()
        self.StegoEncryptPage.setObjectName("StegoEncryptPage")
        self.verticalLayout_29 = QtWidgets.QVBoxLayout(self.StegoEncryptPage)
        self.verticalLayout_29.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_29.setSpacing(0)
        self.verticalLayout_29.setObjectName("verticalLayout_29")
        self.infileframe = QtWidgets.QFrame(self.StegoEncryptPage)
        self.infileframe.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.infileframe.setFrameShadow(QtWidgets.QFrame.Raised)
        self.infileframe.setObjectName("infileframe")
        self.horizontalLayout_34 = QtWidgets.QHBoxLayout(self.infileframe)
        self.horizontalLayout_34.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_34.setSpacing(0)
        self.horizontalLayout_34.setObjectName("horizontalLayout_34")
        self.infiledragdrop = DragDropWidget(self.infileframe)
        self.infiledragdrop.setObjectName("infiledragdrop")
        self.horizontalLayout_35 = QtWidgets.QHBoxLayout(self.infiledragdrop)
        self.horizontalLayout_35.setContentsMargins(3, 0, 3, 0)
        self.horizontalLayout_35.setObjectName("horizontalLayout_35")
        self.infilelabel = QtWidgets.QLabel(self.infiledragdrop)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(25)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.infilelabel.setFont(font)
        self.infilelabel.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.infilelabel.setAlignment(QtCore.Qt.AlignCenter)
        self.infilelabel.setObjectName("infilelabel")
        self.horizontalLayout_35.addWidget(self.infilelabel)
        self.horizontalLayout_34.addWidget(self.infiledragdrop)
        self.verticalLayout_29.addWidget(self.infileframe)
        self.datafileframe = QtWidgets.QFrame(self.StegoEncryptPage)
        self.datafileframe.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.datafileframe.setFrameShadow(QtWidgets.QFrame.Raised)
        self.datafileframe.setObjectName("datafileframe")
        self.horizontalLayout_39 = QtWidgets.QHBoxLayout(self.datafileframe)
        self.horizontalLayout_39.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_39.setSpacing(0)
        self.horizontalLayout_39.setObjectName("horizontalLayout_39")
        self.datafiledragdrop = DragDropWidget(self.datafileframe)
        self.datafiledragdrop.setObjectName("datafiledragdrop")
        self.horizontalLayout_40 = QtWidgets.QHBoxLayout(self.datafiledragdrop)
        self.horizontalLayout_40.setContentsMargins(3, 2, 3, 0)
        self.horizontalLayout_40.setSpacing(0)
        self.horizontalLayout_40.setObjectName("horizontalLayout_40")
        self.datafilelabel = QtWidgets.QLabel(self.datafiledragdrop)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(26)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.datafilelabel.setFont(font)
        self.datafilelabel.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.datafilelabel.setAlignment(QtCore.Qt.AlignCenter)
        self.datafilelabel.setObjectName("datafilelabel")
        self.horizontalLayout_40.addWidget(self.datafilelabel)
        self.horizontalLayout_39.addWidget(self.datafiledragdrop)
        self.verticalLayout_29.addWidget(self.datafileframe)
        self.browse = QtWidgets.QFrame(self.StegoEncryptPage)
        self.browse.setMinimumSize(QtCore.QSize(0, 54))
        self.browse.setMaximumSize(QtCore.QSize(16777215, 54))
        self.browse.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.browse.setFrameShadow(QtWidgets.QFrame.Raised)
        self.browse.setObjectName("browse")
        self.verticalLayout_30 = QtWidgets.QVBoxLayout(self.browse)
        self.verticalLayout_30.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_30.setSpacing(0)
        self.verticalLayout_30.setObjectName("verticalLayout_30")
        self.browsefile = DragDropWidget(self.browse)
        self.browsefile.setObjectName("browsefile")
        self.verticalLayout_31 = QtWidgets.QVBoxLayout(self.browsefile)
        self.verticalLayout_31.setContentsMargins(3, 2, 3, 0)
        self.verticalLayout_31.setSpacing(0)
        self.verticalLayout_31.setObjectName("verticalLayout_31")
        self.browselabel = QtWidgets.QLabel(self.browsefile)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(22)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.browselabel.setFont(font)
        self.browselabel.setStyleSheet("border: 2px dashed #aaa;\n"
"color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));\n"
"background-color: qlineargradient(spread:pad, x1:0.462049, y1:0.921, x2:0.452, y2:0, stop:0.174129 rgba(74, 74, 74, 42), stop:0.567164 rgba(78, 59, 58, 30));\n"
"")
        self.browselabel.setAlignment(QtCore.Qt.AlignCenter)
        self.browselabel.setObjectName("browselabel")
        self.verticalLayout_31.addWidget(self.browselabel)
        self.verticalLayout_30.addWidget(self.browsefile)
        self.verticalLayout_29.addWidget(self.browse)
        self.labelsinput = QtWidgets.QFrame(self.StegoEncryptPage)
        self.labelsinput.setMinimumSize(QtCore.QSize(0, 62))
        self.labelsinput.setMaximumSize(QtCore.QSize(16777215, 62))
        self.labelsinput.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.labelsinput.setFrameShadow(QtWidgets.QFrame.Raised)
        self.labelsinput.setObjectName("labelsinput")
        self.horizontalLayout_41 = QtWidgets.QHBoxLayout(self.labelsinput)
        self.horizontalLayout_41.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_41.setSpacing(0)
        self.horizontalLayout_41.setObjectName("horizontalLayout_41")
        self.labels = QtWidgets.QFrame(self.labelsinput)
        self.labels.setMinimumSize(QtCore.QSize(153, 0))
        self.labels.setMaximumSize(QtCore.QSize(153, 16777215))
        self.labels.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.labels.setFrameShadow(QtWidgets.QFrame.Raised)
        self.labels.setObjectName("labels")
        self.verticalLayout_32 = QtWidgets.QVBoxLayout(self.labels)
        self.verticalLayout_32.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_32.setSpacing(0)
        self.verticalLayout_32.setObjectName("verticalLayout_32")
        self.lsblabel = QtWidgets.QLabel(self.labels)
        font = QtGui.QFont()
        font.setFamily("Lemon")
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.lsblabel.setFont(font)
        self.lsblabel.setStyleSheet("color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));")
        self.lsblabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lsblabel.setIndent(2)
        self.lsblabel.setObjectName("lsblabel")
        self.verticalLayout_32.addWidget(self.lsblabel)
        self.nbyteslabel = QtWidgets.QLabel(self.labels)
        font = QtGui.QFont()
        font.setFamily("Lemon")
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.nbyteslabel.setFont(font)
        self.nbyteslabel.setStyleSheet("color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(158, 7, 23, 180), stop:1 rgba(255, 130, 20, 200));")
        self.nbyteslabel.setObjectName("nbyteslabel")
        self.verticalLayout_32.addWidget(self.nbyteslabel)
        self.horizontalLayout_41.addWidget(self.labels)
        self.input = QtWidgets.QFrame(self.labelsinput)
        self.input.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.input.setFrameShadow(QtWidgets.QFrame.Raised)
        self.input.setObjectName("input")
        self.verticalLayout_33 = QtWidgets.QVBoxLayout(self.input)
        self.verticalLayout_33.setContentsMargins(0, 3, 3, 3)
        self.verticalLayout_33.setSpacing(4)
        self.verticalLayout_33.setObjectName("verticalLayout_33")
        self.lsb_2 = QtWidgets.QLineEdit(self.input)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lsb_2.sizePolicy().hasHeightForWidth())
        self.lsb_2.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Courgette")
        font.setPointSize(9)
        self.lsb_2.setFont(font)
        self.lsb_2.setStyleSheet("color: rgb(255, 76, 16);\n"
"background-color: qlineargradient(spread:reflect, x1:1, y1:0.579, x2:0, y2:0.477273, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 55));")
        self.lsb_2.setAlignment(QtCore.Qt.AlignCenter)
        self.lsb_2.setObjectName("lsb_2")
        self.verticalLayout_33.addWidget(self.lsb_2)
        self.nbytes = QtWidgets.QLineEdit(self.input)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.nbytes.sizePolicy().hasHeightForWidth())
        self.nbytes.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Courgette")
        font.setPointSize(9)
        self.nbytes.setFont(font)
        self.nbytes.setStyleSheet("color: rgb(255, 76, 16);\n"
"background-color: qlineargradient(spread:reflect, x1:1, y1:0.579, x2:0, y2:0.477273, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 55));")
        self.nbytes.setAlignment(QtCore.Qt.AlignCenter)
        self.nbytes.setObjectName("nbytes")
        self.verticalLayout_33.addWidget(self.nbytes)
        self.horizontalLayout_41.addWidget(self.input)
        self.verticalLayout_29.addWidget(self.labelsinput)
        self.buttons = QtWidgets.QFrame(self.StegoEncryptPage)
        self.buttons.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.buttons.setFrameShadow(QtWidgets.QFrame.Raised)
        self.buttons.setObjectName("buttons")
        self.horizontalLayout_42 = QtWidgets.QHBoxLayout(self.buttons)
        self.horizontalLayout_42.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_42.setSpacing(0)
        self.horizontalLayout_42.setObjectName("horizontalLayout_42")
        self.forward = QtWidgets.QPushButton(self.buttons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.forward.sizePolicy().hasHeightForWidth())
        self.forward.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(23)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.forward.setFont(font)
        self.forward.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.forward.setObjectName("forward")
        self.horizontalLayout_42.addWidget(self.forward)
        self.backward = QtWidgets.QPushButton(self.buttons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.backward.sizePolicy().hasHeightForWidth())
        self.backward.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Feast of Flesh BB")
        font.setPointSize(23)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.backward.setFont(font)
        self.backward.setStyleSheet("QPushButton {\n"
"    color: rgba(255, 255, 255, 150);\n"
"    background-color: rgba(0, 0, 0, 0);\n"
"    border: 0px solid;\n"
"}\n"
"\n"
"QPushButton::hover {\n"
"    \n"
"    color: rgba(255, 255, 255, 195);\n"
"    border: 0px solid;\n"
"    background-color: qlineargradient(spread:pad, x1:0.46305, y1:0.261, x2:0.478, y2:1, stop:0.268657 rgba(62, 59, 59, 246), stop:1 rgba(211, 113, 27, 125));\n"
"}")
        self.backward.setObjectName("backward")
        self.horizontalLayout_42.addWidget(self.backward)
        self.verticalLayout_29.addWidget(self.buttons)
        self.stackedWidget.addWidget(self.StegoEncryptPage)
        self.verticalLayout_7.addWidget(self.stackedWidget)
        self.Stack.addWidget(self.MacroPage)
        self.verticalLayout_5.addWidget(self.Stack)
        self.horizontalLayout_2.addWidget(self.Pages)
        self.verticalLayout.addWidget(self.Content)
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)
        self.Stack.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "thoryvos"))
        self.ToggleMenu.setText(_translate("MainWindow", "TOGGLE"))
        self.AppName.setText(_translate("MainWindow", "<html><head/><body><p align=\"center\">Thor𝜓vos</p></body></html>"))
        self.CreatedBy.setText(_translate("MainWindow", "Made by Rakshan Sharma"))
        self.Home.setText(_translate("MainWindow", "Home"))
        self.Crypto.setText(_translate("MainWindow", "Crypto"))
        self.FileShare.setText(_translate("MainWindow", "Transfer"))
        self.Stego.setText(_translate("MainWindow", "Stego"))
        self.MarosMenuButton.setText(_translate("MainWindow", "Macros"))
        self.AppNameBig.setText(_translate("MainWindow", "Thor<strong>𝜓vos</strong>"))
        self.AppDesc.setText(_translate("MainWindow", "The all in one audio cryptographic toolkit"))
        self.CryptoPageButton.setText(_translate("MainWindow", "Encryption/\n"
"Decryption"))
        self.TransferPageButton.setText(_translate("MainWindow", "File\n"
"Transfer"))
        self.StegoPageButton.setText(_translate("MainWindow", "Audio\n"
"Steganographer"))
        self.MacroPageButton.setText(_translate("MainWindow", "Macros"))
        self.CryptoDragDropLabel.setText(_translate("MainWindow", "Drag & Drop/\n"
"Click To Add File"))
        self.CryptoSaveLocBrowseL.setText(_translate("MainWindow", "Click To Browse Save Location"))
        self.Password.setPlaceholderText(_translate("MainWindow", "Enter Password Here"))
        self.Encrypt.setText(_translate("MainWindow", "Encrypt"))
        self.Decrypt.setText(_translate("MainWindow", "Decrypt"))
        self.DragDropLabelTransfer.setText(_translate("MainWindow", "Click To Add/\n"
"Drag & Drop Files"))
        self.UrlLabel.setText(_translate("MainWindow", "URL:"))
        self.Url.setPlaceholderText(_translate("MainWindow", "Paste URL Here"))
        self.ButtonTransfer.setText(_translate("MainWindow", "Transfer"))
        self.HideButton.setText(_translate("MainWindow", "Hide Data In a WAV file"))
        self.RecoverButton.setText(_translate("MainWindow", "Recover Data from a WAV file"))
        self.InfileDragDropLabel.setText(_translate("MainWindow", "(Audio File)\n"
"Click To Add/ Drag & Drop Files"))
        self.DatafileDragDropLabel.setText(_translate("MainWindow", "(Data File)\n"
"Click To Add/ Drag & Drop Files"))
        self.SaveLocBrowseStegoLabel.setText(_translate("MainWindow", "Click To Browse Save Location"))
        self.lsb.setPlaceholderText(_translate("MainWindow", "Enter LSB Here (Optional)"))
        self.HideBtn.setText(_translate("MainWindow", "Hide"))
        self.InfileRecLabel.setText(_translate("MainWindow", "(Stego Audio)\n"
" Drag&Drop/Click To Add File"))
        self.OutfileRecLabel.setText(_translate("MainWindow", "Click To Browse Save Location"))
        self.LSBLabel.setText(_translate("MainWindow", "LSB:"))
        self.NBLabel.setText(_translate("MainWindow", "Bytes To Recover:"))
        self.LSB.setPlaceholderText(_translate("MainWindow", "The LSB used during hiding. [Required]"))
        self.NBytes.setPlaceholderText(_translate("MainWindow", "The no. of bytes to recover. [Required]"))
        self.RecButton.setText(_translate("MainWindow", "Recover"))
        self.MoreComingSoon.setText(_translate("MainWindow", "More Macros Coming Soon..."))
        self.EncSteg.setText(_translate(
            "MainWindow", "Encrypt -> Hide \n {AES256}"))
        self.StegEnc.setText(_translate(
            "MainWindow", "Hide -> Encrypt \n (Coming Soon)"))
        self.MInfileLabel.setText(_translate("MainWindow", "(Infile)\n"
"Click To Add/Drag&Drop Files"))
        self.MDatafileLabel.setText(_translate("MainWindow", "(Datafile)\n"
"Click To Add/Drag&Drop Files"))
        self.SaveLocationBrowseLabel.setText(_translate("MainWindow", "Click To Browse Save Location"))
        self.LSBLabel_2.setText(_translate("MainWindow", "LSB:"))
        self.NBytesLabel.setText(_translate("MainWindow", "Bytes To Recover:"))
        self.LSBInput.setPlaceholderText(_translate("MainWindow", "Enter LSB Here. [Required For Backward Circuit]"))
        self.NBytesInput.setPlaceholderText(_translate("MainWindow", "Enter Bytes To Recover Here. [Required For Backward Circuit]"))
        self.Forward.setText(_translate("MainWindow", "Forward Circuit [Enc -> Hide]"))
        self.Backward.setText(_translate("MainWindow", "Backward Circuit [Rec -> Dec]"))
        self.infilelabel.setText(_translate("MainWindow", "(Infile)\n"
"Click To Add/Drag&Drop Files"))
        self.datafilelabel.setText(_translate("MainWindow", "(Datafile)\n"
"Click To Add/Drag&Drop Files"))
        self.browselabel.setText(_translate("MainWindow", "Click To Browse Save File Location"))
        self.lsblabel.setText(_translate("MainWindow", "LSB:"))
        self.nbyteslabel.setText(_translate("MainWindow", "Bytes To Recover:"))
        self.lsb_2.setPlaceholderText(_translate("MainWindow", "Enter LSB Here [Required For Backward Circuit]"))
        self.nbytes.setPlaceholderText(_translate("MainWindow", "Enter No. Of Bytes To Recover Here [Required For Backward Circuit]"))
        self.forward.setText(_translate("MainWindow", "Forward Circuit [Hide -> Enc]"))
        self.backward.setText(_translate("MainWindow", "Backward Circuit [Dec -> Rec]"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
